@@ -10,6 +10,8 @@ has description => 'Generate a .htaccess file for running Slovo under Apache 2/C
 has usage       => sub { shift->extract_usage };
 
 sub run ($self, @args) {
+
+  #TODO: Add option for common aliases to be taken into account when writing
   getopt \@args,
 
     'r|docroot=s'    => \(my $docroot    = ''),
@@ -33,7 +35,8 @@ sub run ($self, @args) {
   my $cgi_file;
   unless ($cgi_script) {
     $cgi_script = $app->moniker . '\.cgi';
-    $cgi_file   = $home->list_tree({max_depth => 1})->first(qr/$cgi_script$/);
+    $cgi_file
+      = $home->list_tree({max_depth => 1})->first(qr/$cgi_script$/) || $cgi_script;
     say 'Assuming CGI script: ' . $cgi_file;
   }
   else { $cgi_file = $cgi_script; }
@@ -122,89 +125,100 @@ __DATA__
 
 @@ a2htaccess
 
-
 # Apache 2 .htaccess configuration for Slovo.
 # Generated by Slovo::Command::Author::generate::a2htaccess using <%= __FILE__ %>.
-# Note!! If you run again `slovo generate a2htaccess` this file will be rewritten.
-# Note! Not sure if the produced .htacces will work fine for you
-# so make sure to test locally first.
+# Note!! If you run again `slovo generate a2htaccess` this file will NOT be
+# rewritten. Note! Not sure if the produced .htacces will work fine for you so
+# make sure to test locally first.
 
 
-# Uncomment the following line when going live.
+# Uncomment the following line when going live or regenerate slovo.cgi:
+# slovo generate cgi_script -f slovo.cgi -m production
 # SetEnv HTTP_MOJO_MODE production
 
 # use utf-8 encoding for anything served text/plain or text/html
 AddDefaultCharset utf-8
 
 # Protect files and directories from prying eyes.
-#<FilesMatch "(templates/|etc/|lib/|log/|t/|_build/|cover_db/|\.(pm|ep|conf|log|t|bak|yml|sqlite|sql)|READM.+|MANIF.+|Build.PL|Build|Makefi.+)$">
-#    #2.2 configuration:
-#    <IfModule !mod_authz_core.c>
-#      Order deny,allow
-#      Deny from all
-#    </IfModule>
-#    #2.4 configuration:
-#    <IfModule mod_authz_core.c>
-#      Require all denied
-#    </IfModule>
-#</FilesMatch>
-#
-Options +Indexes +FollowSymLinks +ExecCGI
+<FilesMatch "(templ/|etc/|lib/|log/|t/|_build/|cover_db/|\.(pmc?|ep|conf|log|t|bak|yml|sqlite|sql)|READM.+|MANIF.+|Build.PL|Build|Makefi.+)$">
+    #2.2 configuration:
+    <IfModule !mod_authz_core.c>
+      Order deny,allow
+      Deny from all
+    </IfModule>
+    #2.4 configuration:
+    <IfModule mod_authz_core.c>
+      Require all denied
+    </IfModule>
+</FilesMatch>
+Options -Indexes +FollowSymLinks +ExecCGI
+
+# Requires mod_expires to be enabled.
+<IfModule mod_expires.c>
+  # Enable expirations.
+  ExpiresActive On
+
+  ExpiresDefault "access plus 1 month"
+  <IfModule mod_headers.c>
+    Header append Cache-Control "public"
+  </IfModule>
+  <FilesMatch <%=$cgi_script%>>
+    # Do not allow slovo responses to be cached unless they explicitly send
+    # cache headers themselves.
+    ExpiresActive Off
+  </FilesMatch>
+</IfModule>
 
-## Requires mod_expires to be enabled.
-#<IfModule mod_expires.c>
-#  # Enable expirations.
-#  ExpiresActive On
-#
-#  ExpiresDefault "access plus 1 month"
-#  <IfModule mod_headers.c>
-#    Header append Cache-Control "public"
-#  </IfModule>
-#  <FilesMatch <%=$cgi_script%>>
-#    # Do not allow slovo responses to be cached unless they explicitly send cache
-#    # headers themselves.
-#    ExpiresActive Off
-#  </FilesMatch>
-#</IfModule>
 <Files ~ "^(<%=$cgi_script%>)$">
     SetHandler  cgi-script
 </Files>
 
-# Make Slovo handle any 404 errors.
-ErrorDocument 404 /<%=$moniker%>/<%=$cgi_script%>
-DirectoryIndex /<%=$moniker%>/<%=$cgi_script%>
 
 # Some more security. Redefine the mime type for the most common types of scripts
 AddType text/plain .shtml .php .php3 .phtml .phtm .pl .py
 
-#<IfModule mod_rewrite.c>
-#  RewriteEngine on
-#  # Make sure Authorization HTTP header is available to Slovo
-#  # even when running as CGI or FastCGI.
-#  # RewriteRule ^ - [E=HTTP_AUTHORIZATION:%{HTTP:Authorization}]
-#
-#  # Block access to "hidden" directories whose names begin with a period.
-#  RewriteRule "(^|/)\." - [F]
-#
-#  # To redirect all users to access the site WITHOUT the 'www.' prefix,
-#  # (http://www.example.com/... will be redirected to http://example.com/...)
-#  # uncomment the following:
-#  RewriteCond %{HTTP_HOST} ^www\.(.+)$ [NC]
-#  RewriteRule ^ http%{ENV:protossl}://%1%{REQUEST_URI} [L,R=301]
-#
-#  # Redirect all requests for Slovo static files to public/ directory.
-#  RewriteCond %{REQUEST_FILENAME} !-f
-#  RewriteCond %{REQUEST_FILENAME} !-d
-#  RewriteRule ^((css|doc|fonts|img|js|vendor|favicon|index)\b.*)$  /<%=$moniker%>/domove/%{HTTP_HOST}/public/$1 [L]
-#  RewriteRule ^(.*\.html)$  /<%=$moniker%>/domove/%{HTTP_HOST}/public/cached/$1 [L]
-#
-#  # If your site is running in a VirtualDocumentRoot at http://example.com/,
-#  # use the following line:
-#  RewriteBase /
-#
-#  RewriteCond %{REQUEST_FILENAME} !-f
-#  RewriteCond %{REQUEST_FILENAME} !-d
-#  RewriteRule (.*) /<%=$moniker%><%=$cgi_script%>/$1 [L]
-#
-#</IfModule>
+# Make Slovo serve as DirectoryIndex and handle any 404 errors.
+DirectoryIndex /<%=$moniker%>/<%=$cgi_script%>
+ErrorDocument 404 /<%=$moniker%>/<%=$cgi_script%>/%{REQUEST_URI}
+
+<IfModule mod_rewrite.c>
+  RewriteEngine on
+  RewriteBase /
+
+  # Do not apply rules when requesting "favicon.ico"
+  RewriteCond %{REQUEST_FILENAME} favicon.ico [NC]
+  RewriteRule .* - [END]
+
+  # Do not apply rules when requesting "<%=$cgi_script%>"
+  RewriteCond %{SCRIPT_FILENAME} <%=$cgi_script%> [NC]
+  RewriteRule .* - [NE,END]
+
+  # Redirect all requests for Slovo static files to respective domain's public/ directory.
+  # /css/fonts.css becomes /domove/t.com/public/css/fonts.css
+  RewriteCond %{REQUEST_FILENAME} !-f
+  RewriteCond %{REQUEST_FILENAME} !-d
+  # Match xn--b1arjbl.xn--90ae out of www.xn--b1arjbl.xn--90ae
+  RewriteCond %{HTTP_HOST} ([\w\-]+.[\w\-]+)$
+  RewriteCond %{DOCUMENT_ROOT}/<%=$moniker%>/domove/%1/public/$1 -f
+  RewriteRule ^((?:css|img|js|fonts)/.+)$  /<%=$moniker%>/domove/%1/public/$1 [NE,END]
+
+  # t.com/about-en-us.html becomes t.com/domove/t.com/public/cached/about-en-us.html
+  RewriteCond %{REQUEST_FILENAME} !-f
+  RewriteCond %{REQUEST_FILENAME} !-d
+  RewriteCond %{HTTP_HOST} ([\w\-]+.[\w\-]+)$
+  RewriteCond %{DOCUMENT_ROOT}/<%=$moniker%>/domove/%1/public/cached/$1 -f
+  RewriteRule ^(.+(?!\.cgi).+\.html)$  /<%=$moniker%>/domove/%1/public/cached/$1 [NE,END]
+
+<% if ($app->mode =~/^prod/) { %>
+  # ONLY on production: To redirect all users to access the site WITHOUT the
+  # '(www|qa|dev).' prefix and switch ON SSL (http://www.example.com/... will
+  # be redirected to http://example.com/...) uncomment the following:
+  RewriteCond %{HTTP_HOST} ^(.+)$ [NC]
+  RewriteRule ^ http%{ENV:protossl}://%1%{REQUEST_URI} [NE,L,R=301]
+<% } %>
+
+  RewriteCond %{REQUEST_FILENAME} !-f
+  RewriteCond %{REQUEST_FILENAME} !-d
+  RewriteRule ^((?!\.cgi).+(?!\.html))$  /<%=$moniker%>/<%=$cgi_script%>/$1 [QSA,NE,END]
+</IfModule>
 
